#![feature(lint_reasons)]

#[macro_use]
pub mod util {
    macro_rules! gen_attr {
        ($name:literal = $out:expr) => {
            quick_xml::events::attributes::Attribute {
                key: quick_xml::name::QName($name),
                value: std::borrow::Cow::from(($out).to_string().into_bytes()),
            }
        };
    }

    macro_rules! gen_attrs {
        ($($name:literal = $out:expr),+) => {
            vec![
                $(gen_attr!($name = $out)),+
            ]
        };
    }

    macro_rules! gen_attrs_with_conds {
        ($($name:literal = $out:expr),+, $($cond:expr => $name_:literal = $out_:expr),+) => {
            {
                let mut r = gen_attrs![$($name = $out),+];
                $(if $cond {
                    r.push(gen_attr!($name_ = $out_));
                })+
                r
            }
        };
    }
}

pub mod codegen;
pub mod types;
pub use types::nodes::Node;

#[cfg(test)]
mod tests;
